[Python-modules-commits] [pylibmc] 13/18: Fix spelling of "occurred" in src/_pylibmcmodule.c.

Michael Fladischer fladi at moszumanska.debian.org
Mon Jul 24 13:23:57 UTC 2017


This is an automated email from the git hooks/post-receive script.

fladi pushed a commit to branch master
in repository pylibmc.

commit daf99b7f6a876d506a180a2fca1a6ddc4257488c
Author: Michael Fladischer <FladischerMichael at fladi.at>
Date:   Fri May 27 10:02:02 2016 +0200

    Fix spelling of "occurred" in src/_pylibmcmodule.c.
---
 src/_pylibmcmodule.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/_pylibmcmodule.c b/src/_pylibmcmodule.c
index 1ce5a6a..642c020 100644
--- a/src/_pylibmcmodule.c
+++ b/src/_pylibmcmodule.c
@@ -1687,7 +1687,7 @@ memcached_return pylibmc_memcached_fetch_multi(memcached_st *mc, pylibmc_mget_re
      * Takes a set of keys given by *keys*, and stuffs the results into heap
      * memory returned by *results*.
      *
      * If an error occured during retrieval, this function returns
      * non-MEMCACHED_SUCCESS and *err_func* will point to a useful error
      * function name.
      *
@@ -2325,7 +2325,7 @@ static PyObject *PylibMC_Client_get_stats(PylibMC_Client *self, PyObject *args)
 
     if (rc != MEMCACHED_SUCCESS) {
         if (!PyErr_Occurred())
-            PyErr_SetString(PyExc_RuntimeError, "unknown error occured");
+            PyErr_SetString(PyExc_RuntimeError, "unknown error occurred");
         Py_DECREF(context.retval);
         context.retval = NULL;
     }
@@ -1687,7 +1687,7 @@ memcached_return pylibmc_memcached_fetch_multi(memcached_st *mc, pylibmc_mget_re
      * memory returned by *results*.
      *
-     * If an error occured during retrieval, this function returns
+     * If an error occurred during retrieval, this function returns
      * non-MEMCACHED_SUCCESS and *err_func* will point to a useful error
      * function name.

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/python-modules/packages/pylibmc.git



More information about the Python-modules-commits mailing list